==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfLayerOutline.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLayerOutline(SpireObject):
    """
    Represent the recommended order for presentation of optional content
    groups in user interface.
    Reference "Optional content configuration dictionary's entry order".
    """

    @dispatch
    def AddGroup(self, name: str) -> 'PdfLayerOutline':
        """
        Add a sub group outline.

        Args:
            name: Group name.

        Returns:
            Sub group outline.
        """
        GetDllLibPdf().PdfLayerOutline_AddGroup.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfLayerOutline_AddGroup.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayerOutline_AddGroup(self.Ptr, name)
        ret = None if intPtr == None else PdfLayerOutline(intPtr)
        return ret

    @dispatch
    def AddGroup(self, layer: PdfLayer) -> 'PdfLayerOutline':
        """
        Add a outline entry of the pdf layer with a sub group outline.

        Args:
            layer: Pdf layer

        Returns:
            Sub group outline.
        """
        intPtrlayer: c_void_p = layer.Ptr

        GetDllLibPdf().PdfLayerOutline_AddGroupL.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLayerOutline_AddGroupL.restype = c_void_p
        intPtr = GetDllLibPdf().PdfLayerOutline_AddGroupL(self.Ptr, intPtrlayer)
        ret = None if intPtr == None else PdfLayerOutline(intPtr)
        return ret

    def AddEntry(self, layer: 'PdfLayer'):
        """
        Add a outline entry of the pdf layer.

        Args:
            layer: Pdf layer
        """
        intPtrlayer: c_void_p = layer.Ptr

        GetDllLibPdf().PdfLayerOutline_AddEntry.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLayerOutline_AddEntry(self.Ptr, intPtrlayer)

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfLayerOutline.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfLayerOutline(SpireObject):
    """
    Represent the recommended order for presentation of optional content
    groups in user interface.
    Reference "Optional content configuration dictionary's entry order".
    """

    @dispatch
    def AddGroup(self, name: str) -> 'PdfLayerOutline':
        """
        Add a sub group outline.

        Args:
            name: Group name.

        Returns:
            Sub group outline.
        """
        GetDllLibPdf().PdfLayerOutline_AddGroup.argtypes = [c_void_p, c_wchar_p]
        GetDllLibPdf().PdfLayerOutline_AddGroup.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayerOutline_AddGroup,self.Ptr, name)
        ret = None if intPtr == None else PdfLayerOutline(intPtr)
        return ret

    @dispatch
    def AddGroup(self, layer: PdfLayer) -> 'PdfLayerOutline':
        """
        Add a outline entry of the pdf layer with a sub group outline.

        Args:
            layer: Pdf layer

        Returns:
            Sub group outline.
        """
        intPtrlayer: c_void_p = layer.Ptr

        GetDllLibPdf().PdfLayerOutline_AddGroupL.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfLayerOutline_AddGroupL.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfLayerOutline_AddGroupL,self.Ptr, intPtrlayer)
        ret = None if intPtr == None else PdfLayerOutline(intPtr)
        return ret

    def AddEntry(self, layer: 'PdfLayer'):
        """
        Add a outline entry of the pdf layer.

        Args:
            layer: Pdf layer
        """
        intPtrlayer: c_void_p = layer.Ptr

        GetDllLibPdf().PdfLayerOutline_AddEntry.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfLayerOutline_AddEntry,self.Ptr, intPtrlayer)
